==> opam-debug-2.3.0-3-x86_64.pkg.tar.zst: usr/src/debug/opam/opam-full-2.3.0/_build/default/src_ext/spdx_licenses/src/parser.ml <==
type token =
  | ID of (
# 3 "src_ext/spdx_licenses/src/parser.mly"
        string
# 6 "src_ext/spdx_licenses/src/parser.ml"
)
  | IDPLUS of (
# 4 "src_ext/spdx_licenses/src/parser.mly"
        string
# 11 "src_ext/spdx_licenses/src/parser.ml"
)
  | REF of (
# 5 "src_ext/spdx_licenses/src/parser.mly"
        string option * string
# 16 "src_ext/spdx_licenses/src/parser.ml"
)
  | WITH
  | AND
  | OR
  | LPAREN
  | RPAREN
  | EOF

open Parsing
let _ = parse_error;;
let yytransl_const = [|
  260 (* WITH *);
  261 (* AND *);
  262 (* OR *);
  263 (* LPAREN *);
  264 (* RPAREN *);
    0 (* EOF *);
    0|]

let yytransl_block = [|
  257 (* ID *);
  258 (* IDPLUS *);
  259 (* REF *);
    0|]

let yylhs = "\255\255\
\001\000\003\000\003\000\003\000\002\000\002\000\002\000\002\000\
\002\000\000\000"

let yylen = "\002\000\
\002\000\001\000\001\000\001\000\001\000\003\000\003\000\003\000\
\003\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\002\000\003\000\004\000\000\000\010\000\000\000\
\000\000\000\000\000\000\000\000\001\000\000\000\009\000\007\000\
\000\000\006\000"

let yydgoto = "\002\000\
\007\000\008\000\009\000"

let yysindex = "\255\255\
\002\255\000\000\000\000\000\000\000\000\002\255\000\000\006\000\
\003\255\006\255\002\255\002\255\000\000\007\255\000\000\000\000\
\008\255\000\000"

let yyrindex = "\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\002\000\000\000"

let yygindex = "\000\000\
\000\000\004\000\000\000"

let yytablesize = 268
let yytable = "\001\000\
\005\000\008\000\003\000\004\000\005\000\013\000\014\000\018\000\
\006\000\010\000\011\000\012\000\011\000\015\000\016\000\017\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\005\000\005\000\008\000\
\005\000\008\000\011\000\012\000"

let yycheck = "\001\000\
\000\000\000\000\001\001\002\001\003\001\000\000\004\001\001\001\
\007\001\006\000\005\001\006\001\005\001\008\001\011\000\012\000\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\005\001\006\001\006\001\
\008\001\008\001\005\001\006\001"

let yynames_const = "\
  WITH\000\
  AND\000\
  OR\000\
  LPAREN\000\
  RPAREN\000\
  EOF\000\
  "

let yynames_block = "\
  ID\000\
  IDPLUS\000\
  REF\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'body) in
    Obj.repr(
# 21 "src_ext/spdx_licenses/src/parser.mly"
               ( _1 )
# 166 "src_ext/spdx_licenses/src/parser.ml"
               : Types.t))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 24 "src_ext/spdx_licenses/src/parser.mly"
       ( Types.LicenseID _1 )
# 173 "src_ext/spdx_licenses/src/parser.ml"
               : 'simple))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 25 "src_ext/spdx_licenses/src/parser.mly"
           ( Types.LicenseIDPlus _1 )
# 180 "src_ext/spdx_licenses/src/parser.ml"
               : 'simple))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string option * string) in
    Obj.repr(
# 26 "src_ext/spdx_licenses/src/parser.mly"
        ( let (doc, license) = _1 in
          Types.LicenseRef {Types.document_ref = doc; license_ref = license} )
# 188 "src_ext/spdx_licenses/src/parser.ml"
               : 'simple))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'simple) in
    Obj.repr(
# 30 "src_ext/spdx_licenses/src/parser.mly"
           ( Types.Simple _1 )
# 195 "src_ext/spdx_licenses/src/parser.ml"
               : 'body))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'simple) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 31 "src_ext/spdx_licenses/src/parser.mly"
                   ( Types.WITH (_1, _3) )
# 203 "src_ext/spdx_licenses/src/parser.ml"
               : 'body))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'body) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'body) in
    Obj.repr(
# 32 "src_ext/spdx_licenses/src/parser.mly"
                  ( Types.AND (_1, _3) )
# 211 "src_ext/spdx_licenses/src/parser.ml"
               : 'body))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'body) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'body) in
    Obj.repr(
# 33 "src_ext/spdx_licenses/src/parser.mly"
                 ( Types.OR (_1, _3) )
# 219 "src_ext/spdx_licenses/src/parser.ml"
               : 'body))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'body) in
    Obj.repr(
# 34 "src_ext/spdx_licenses/src/parser.mly"
                       ( _2 )
# 226 "src_ext/spdx_licenses/src/parser.ml"
               : 'body))
(* Entry main *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let main (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : Types.t)

==> opam-debug-2.4.1-1-x86_64.pkg.tar.zst: usr/src/debug/opam/opam-full-2.4.1/_build/default/src_ext/spdx_licenses/src/parser.ml <==
type token =
  | ID of (
# 3 "src_ext/spdx_licenses/src/parser.mly"
        string
# 6 "src_ext/spdx_licenses/src/parser.ml"
)
  | IDPLUS of (
# 4 "src_ext/spdx_licenses/src/parser.mly"
        string
# 11 "src_ext/spdx_licenses/src/parser.ml"
)
  | REF of (
# 5 "src_ext/spdx_licenses/src/parser.mly"
        string option * string
# 16 "src_ext/spdx_licenses/src/parser.ml"
)
  | ADREF of (
# 6 "src_ext/spdx_licenses/src/parser.mly"
        string option * string
# 21 "src_ext/spdx_licenses/src/parser.ml"
)
  | WITH
  | AND
  | OR
  | LPAREN
  | RPAREN
  | EOF

open Parsing
let _ = parse_error;;
let yytransl_const = [|
  261 (* WITH *);
  262 (* AND *);
  263 (* OR *);
  264 (* LPAREN *);
  265 (* RPAREN *);
    0 (* EOF *);
    0|]

let yytransl_block = [|
  257 (* ID *);
  258 (* IDPLUS *);
  259 (* REF *);
  260 (* ADREF *);
    0|]

let yylhs = "\255\255\
\001\000\003\000\003\000\003\000\004\000\004\000\002\000\002\000\
\002\000\002\000\002\000\000\000"

let yylen = "\002\000\
\002\000\001\000\001\000\001\000\001\000\001\000\001\000\003\000\
\003\000\003\000\003\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\002\000\003\000\004\000\000\000\012\000\000\000\
\000\000\000\000\000\000\000\000\001\000\000\000\011\000\009\000\
\000\000\005\000\006\000\008\000"

let yydgoto = "\002\000\
\007\000\008\000\009\000\020\000"

let yysindex = "\255\255\
\002\255\000\000\000\000\000\000\000\000\002\255\000\000\006\000\
\008\255\010\255\002\255\002\255\000\000\007\255\000\000\000\000\
\001\255\000\000\000\000\000\000"

let yyrindex = "\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\002\000\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\003\000\000\000\000\000"

let yytablesize = 269
let yytable = "\001\000\
\007\000\010\000\003\000\004\000\005\000\013\000\011\000\018\000\
\010\000\006\000\019\000\000\000\014\000\016\000\017\000\011\000\
\012\000\000\000\015\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\007\000\007\000\
\010\000\007\000\010\000\011\000\012\000"

let yycheck = "\001\000\
\000\000\000\000\001\001\002\001\003\001\000\000\006\001\001\001\
\006\000\008\001\004\001\255\255\005\001\011\000\012\000\006\001\
\007\001\255\255\009\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\006\001\007\001\
\007\001\009\001\009\001\006\001\007\001"

let yynames_const = "\
  WITH\000\
  AND\000\
  OR\000\
  LPAREN\000\
  RPAREN\000\
  EOF\000\
  "

let yynames_block = "\
  ID\000\
  IDPLUS\000\
  REF\000\
  ADREF\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'body) in
    Obj.repr(
# 22 "src_ext/spdx_licenses/src/parser.mly"
               ( _1 )
# 173 "src_ext/spdx_licenses/src/parser.ml"
               : Types.t))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 25 "src_ext/spdx_licenses/src/parser.mly"
       ( Types.LicenseID _1 )
# 180 "src_ext/spdx_licenses/src/parser.ml"
               : 'simple))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 26 "src_ext/spdx_licenses/src/parser.mly"
           ( Types.LicenseIDPlus _1 )
# 187 "src_ext/spdx_licenses/src/parser.ml"
               : 'simple))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string option * string) in
    Obj.repr(
# 27 "src_ext/spdx_licenses/src/parser.mly"
        ( let (document_ref, license_ref) = _1 in
          Types.LicenseRef {Types.document_ref; license_ref} )
# 195 "src_ext/spdx_licenses/src/parser.ml"
               : 'simple))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 31 "src_ext/spdx_licenses/src/parser.mly"
       ( Types.Exception _1 )
# 202 "src_ext/spdx_licenses/src/parser.ml"
               : 'addition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string option * string) in
    Obj.repr(
# 32 "src_ext/spdx_licenses/src/parser.mly"
          ( let (document_ref, addition_ref) = _1 in
            Types.AdditionRef {Types.document_ref; addition_ref} )
# 210 "src_ext/spdx_licenses/src/parser.ml"
               : 'addition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'simple) in
    Obj.repr(
# 36 "src_ext/spdx_licenses/src/parser.mly"
           ( Types.Simple _1 )
# 217 "src_ext/spdx_licenses/src/parser.ml"
               : 'body))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'simple) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'addition) in
    Obj.repr(
# 37 "src_ext/spdx_licenses/src/parser.mly"
                         ( Types.WITH (_1, _3) )
# 225 "src_ext/spdx_licenses/src/parser.ml"
               : 'body))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'body) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'body) in
    Obj.repr(
# 38 "src_ext/spdx_licenses/src/parser.mly"
                  ( Types.AND (_1, _3) )
# 233 "src_ext/spdx_licenses/src/parser.ml"
               : 'body))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'body) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'body) in
    Obj.repr(
# 39 "src_ext/spdx_licenses/src/parser.mly"
                 ( Types.OR (_1, _3) )
# 241 "src_ext/spdx_licenses/src/parser.ml"
               : 'body))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'body) in
    Obj.repr(
# 40 "src_ext/spdx_licenses/src/parser.mly"
                       ( _2 )
# 248 "src_ext/spdx_licenses/src/parser.ml"
               : 'body))
(* Entry main *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let main (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : Types.t)
